<template>
  <div class="app-container">
    <el-row :gutter="20">
      <!--感知设备-->
      <el-col :span="4" :xs="24">
        <div class="head-container">
          <el-tree
            :data="equOptions"
            ref="tree"
            node-key="id"
            highlight-current
            @node-click="handleNodeClick"
          />
        </div>
      </el-col>
      <!--设备推送数据-->
      <el-col :span="20" :xs="24">
        <el-form
          :model="queryParams"
          ref="queryForm"
          size="small"
          :inline="true"
          v-show="showSearch"
          label-width="68px"
        >
          <el-form-item label="采集时间">
            <el-date-picker
              v-model="dateRange"
              style="width: 240px"
              value-format="yyyy-MM-dd HH:mm:ss"
              type="datetimerange"
              range-separator="-"
              start-placeholder="开始日期"
              end-placeholder="结束日期"
            ></el-date-picker>
          </el-form-item>
          <el-form-item>
            <el-button
              type="primary"
              icon="el-icon-search"
              size="mini"
              @click="handleQuery"
              >搜索</el-button
            >
            <el-button icon="el-icon-refresh" size="mini" @click="resetQuery"
              >重置</el-button
            >
            <el-col :span="1.5">
              <el-button
                type="danger"
                plain
                icon="el-icon-delete"
                size="mini"
                :disabled="multiple"
                @click="handleDelete"
                >删除</el-button
              >
            </el-col>
          </el-form-item>
        </el-form>

        <el-table
          @selection-change="handleSelectionChange"
          v-loading="loading"
          :data="equDataList"
          table-layout="auto"
          fit
        >
          <el-table-column type="selection" width="55"></el-table-column>
          <el-table-column type="index" width="50" label="序号" />
          <el-table-column
            v-for="(col, index) in columns"
            :key="index"
            :label="col.param"
            :prop="col.paramCode"
            min-width="150"
            align="center"
          />
          <el-table-column
            label="操作"
            align="center"
            class-name="small-padding fixed-width"
            min-width="100"
          >
            <template slot-scope="scope">
              <el-button
                size="mini"
                type="text"
                icon="el-icon-edit"
                @click="handleUpdate(scope.row)"
                v-hasPermi="['system:supplement:edit']"
                >修改</el-button
              >
              <el-button
                size="mini"
                type="text"
                icon="el-icon-delete"
                @click="handleDelete(scope.row)"
                v-hasPermi="['system:supplement:remove']"
                >删除</el-button
              >
            </template>
          </el-table-column>
        </el-table>

        <pagination
          v-show="total > 0"
          :total="total"
          :page.sync="queryParams.pageNum"
          :limit.sync="queryParams.pageSize"
          @pagination="getList"
        />
      </el-col>
    </el-row>
    <!-- 添加或修改舰船对话框 -->
    <el-dialog :title="title" :visible.sync="open" width="500px" append-to-body>
      <el-form ref="form" :model="form" label-width="150px">
        <div v-for="(col, index) in columns">
          <el-form-item
            v-if="col.paramCode !== 'createTime' && col.paramCode !== 'updateTime'"
            :label="col.param"
            :prop="col.paramCode"
          >
            <el-input v-model="form[col.paramCode]" placeholder="请输入" />
          </el-form-item>
        </div>
      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button type="primary" @click="submitForm">确 定</el-button>
        <el-button @click="cancel">取 消</el-button>
      </div>
    </el-dialog>
  </div>
</template>

<script>
import {
  listUser,
  getUser,
  delUser,
  addUser,
  updateUser,
  resetUserPwd,
  changeUserStatus,
  deptTreeSelect,
} from "@/api/system/user";
import {
  equTree,
  dataList,
  dataPageList,
  updateResData,
  delResData,
  getEquTypeByid,
} from "@/api/manage/equRes";
import { getToken } from "@/utils/auth";
import Treeselect from "@riophae/vue-treeselect";
import "@riophae/vue-treeselect/dist/vue-treeselect.css";

export default {
  name: "User",
  dicts: ["sys_normal_disable", "sys_user_sex"],
  components: { Treeselect },
  data() {
    return {
      // 遮罩层
      loading: true,
      // 选中数组
      ids: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      // 显示搜索条件
      showSearch: true,
      // 总条数
      total: 0,
      // 用户表格数据
      equDataList: null,
      // 弹出层标题
      title: "",
      // 设备树选项
      equOptions: undefined,
      // 是否显示弹出层
      open: false,
      // 部门名称
      deptName: undefined,
      // 默认密码
      initPassword: undefined,
      // 日期范围
      dateRange: [],
      // 默认选中的节点
      defaultCheckedKeys: 15,
      defaultExpandedKeys: [],
      // 岗位选项
      postOptions: [],
      // 角色选项
      roleOptions: [],
      // 表单参数
      form: {},
      defaultProps: {
        children: "children",
        label: "label",
      },
      // 用户导入参数
      upload: {
        // 是否显示弹出层（用户导入）
        open: false,
        // 弹出层标题（用户导入）
        title: "",
        // 是否禁用上传
        isUploading: false,
        // 是否更新已经存在的用户数据
        updateSupport: 0,
        // 设置上传的请求头部
        headers: { Authorization: "Bearer " + getToken() },
        // 上传的地址
        url: process.env.VUE_APP_BASE_API + "/system/user/importData",
      },
      // 查询参数
      queryParams: {
        startTime: null,
        endTime: null,
        pageSize: 20,
        pageNum: 0,
        id: 0,
      },
      // 列信息
      columns: [
        { key: 0, label: `用户编号`, visible: true },
        { key: 1, label: `用户名称`, visible: true },
        { key: 2, label: `用户昵称`, visible: true },
        { key: 3, label: `部门`, visible: true },
        { key: 4, label: `手机号码`, visible: true },
        { key: 5, label: `状态`, visible: true },
        { key: 6, label: `创建时间`, visible: true },
      ],
      // 表单校验
    };
  },
  watch: {
    // 根据名称筛选部门树
    deptName(val) {
      this.$refs.tree.filter(val);
    },
    equOptions(val) {
      if (val.length > 0) {
        this.$nextTick(() => {
          this.$refs.tree.setCurrentKey(val[0].children[0].id);
          this.handleNodeClick(val[0].children[0]);
        });
      }
    },
  },
  created() {
    this.getEquTree();
    this.getConfigKey("sys.user.initPassword").then((response) => {
      this.initPassword = response.msg;
    });
  },
  methods: {
    /** 查询列表 */
    getList() {
      if (!this.dateRange) {
        this.resetQuery();
      }

      this.queryParams.startTime = this.dateRange[0];
      this.queryParams.endTime = this.dateRange[1];
      this.loading = true;
      dataPageList(this.queryParams).then((response) => {
        /** this.userList = response.rows; */
        this.total = response.data.dataList.total;
        this.equDataList = response.data.dataList.rows;
        response.data.tableList.push({
          id: null,
          deviceName: null,
          deviceAddress: 0,
          ip: null,
          port: null,
          functionCode: 0,
          registerAdress: null,
          registerCount: null,
          crc: null,
          dataType: null,
          param: "更新时间",
          paramCode: "updateTime",
          unit: null,
        });
        this.columns = response.data.tableList.reverse();

        this.loading = false;
      });
    },
    /** 查询设备下拉树结构 */
    getEquTree() {
      equTree().then((response) => {
        this.equOptions = response.data;
        // console.log(this.equOptions);
        var datas = response.data;
        datas.forEach((val, key) => {
          if (val.children) {
            this.defaultExpandedKeys.push(val.id);
          }
        });
        this.defaultCheckedKeys = response.data[0].children[0].id;
      });
    },
    // 节点单击事件
    handleNodeClick(data) {
      if (data.disabled) {
        return;
      }
      this.queryParams.id = data.id;
      this.handleQuery();
    },

    // 取消按钮
    cancel() {
      this.open = false;
      this.reset();
    },
    // 表单重置
    reset() {
      this.form = {
        userId: undefined,
        deptId: undefined,
        userName: undefined,
        nickName: undefined,
        password: undefined,
        phonenumber: undefined,
        email: undefined,
        sex: undefined,
        status: "0",
        remark: undefined,
        postIds: [],
        roleIds: [],
      };
      this.resetForm("form");
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.queryParams.pageNum = 1;
      this.getList();
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.dateRange = [];
      this.resetForm("queryForm");
      this.queryParams.deptId = undefined;
      this.$refs.tree.setCurrentKey(null);
      this.handleQuery();
    },
    // 多选框选中数据
    handleSelectionChange(selection) {
      this.ids = selection.map((item) => item.id);
      this.single = selection.length != 1;
      this.multiple = !selection.length;
    },

    /** 修改按钮操作 */
    handleUpdate(row) {
      const { updateTime, ...formData } = row;
      this.form = formData;
      this.open = true;
      this.title = "修改数据";
    },
    /** 提交按钮 */
    submitForm() {
      getEquTypeByid(this.queryParams.id).then((response) => {
        updateResData(response.data, this.form).then((response) => {
          this.$modal.msgSuccess("修改成功");
          this.open = false;
          this.getList();
        });
      });
    },
    /** 删除按钮操作 */
    handleDelete(row) {
      const equid = this.queryParams.id;
      const userIds = row.id || this.ids;
      this.$modal
        .confirm("是否确认删除数据项？")
        .then(function () {
          return getEquTypeByid(equid);
        })
        .then((res) => {
          let idsArr = Array.isArray(userIds) ? userIds : [userIds];
          delResData(res.data, idsArr).then((response) => {
            this.$modal.msgSuccess("删除成功");
            this.getList();
          });
        })
        .catch(() => {});
    },
  },
};
</script>
